# features
- search by name/tag functionality
- some form of result viewer
    - for plugins
    - general overview
- menu dynamic plugin installation+flags (needs uv)
- log preview
- command preview
- tox-like multi python-version testing

# generals
- test strategy

# optionals
- align result Icons better on test tree
- using something like watchfiles to detect filechanges and
update the test_tree accordingly (or just stick with a manual refresh)

# fixes
- fix display of skip reason after reset
